@@ -154,9 +154,15 @@
       }
       this.cols_per_screen = cols_per_screen;
       if (this.use_document_margins && this.document_margins !== null) {
-        this.margin_top = this.document_margins.top || margin_top;
-        this.margin_bottom = this.document_margins.bottom || margin_bottom;
-        this.margin_side = this.document_margins.left || this.document_margins.right || margin_side;
+        this.margin_top = this.document_margins.top !== null ? this.document_margins.top : margin_top;
+        this.margin_bottom = this.document_margins.bottom !== null ? this.document_margins.bottom : margin_bottom;
+        if (this.document_margins.left !== null) {
+          this.margin_side = this.document_margins.left;
+        } else if (this.document_margins.right !== null) {
+          this.margin_side = this.document_margins.right;
+        } else {
+          this.margin_side = margin_side;
+        }
         this.effective_margin_top = this.margin_top;
         return this.effective_margin_bottom = this.margin_bottom;
       } else {
@@ -338,7 +344,7 @@
     };
 
     PagedDisplay.prototype.update_header_footer = function(pagenum) {
-      var author, cls, section, title;
+      var author, cls, section, title, tl_section;
       if (this.hf_style !== null) {
         if (pagenum % 2 === 1) {
           cls = "even_page";
@@ -349,13 +355,14 @@
         title = py_bridge.title();
         author = py_bridge.author();
         section = py_bridge.section();
+        tl_section = py_bridge.tl_section();
       }
       if (this.header !== null) {
-        this.header.innerHTML = this.header_template.replace(/_PAGENUM_/g, pagenum + "").replace(/_TITLE_/g, title + "").replace(/_AUTHOR_/g, author + "").replace(/_SECTION_/g, section + "");
+        this.header.innerHTML = this.header_template.replace(/_PAGENUM_/g, pagenum + "").replace(/_TITLE_/g, title + "").replace(/_AUTHOR_/g, author + "").replace(/_TOP_LEVEL_SECTION_/g, tl_section + "").replace(/_SECTION_/g, section + "");
         runscripts(this.header);
       }
       if (this.footer !== null) {
-        this.footer.innerHTML = this.footer_template.replace(/_PAGENUM_/g, pagenum + "").replace(/_TITLE_/g, title + "").replace(/_AUTHOR_/g, author + "").replace(/_SECTION_/g, section + "");
+        this.footer.innerHTML = this.footer_template.replace(/_PAGENUM_/g, pagenum + "").replace(/_TITLE_/g, title + "").replace(/_AUTHOR_/g, author + "").replace(/_TOP_LEVEL_SECTION_/g, tl_section + "").replace(/_SECTION_/g, section + "");
         return runscripts(this.footer);
       }
     };
