@@ -14,7 +14,7 @@ from calibre.ebooks.oeb.base import XHTML, XHTML_NS, urlnormalize
 from calibre.ebooks.oeb.stylizer import Stylizer
 from calibre.ebooks.oeb.transforms.flatcss import KeyMapper
 from calibre.ebooks.mobi.utils import convert_color_for_font_tag
-from calibre.utils.magick.draw import identify_data
+from calibre.utils.imghdr import identify
 
 MBP_NS = 'http://mobipocket.com/ns/mbp'
 def MBP(name):
@@ -445,8 +445,8 @@ class MobiMLizer(object):
                             href)
                 else:
                     try:
-                        width, height = identify_data(item.data)[:2]
-                    except:
+                        width, height = identify(item.data)[1:]
+                    except Exception:
                         self.oeb.logger.warn('Invalid image:', href)
                     else:
                         if 'width' not in istate.attrib and 'height' not in \
@@ -468,9 +468,13 @@ class MobiMLizer(object):
                                     pass
                                 istate.attrib['height'] = str(int(height))
                         item.unload_data_from_memory()
-        elif tag == 'hr' and asfloat(style['width']) > 0:
-            prop = style['width'] / self.profile.width
-            istate.attrib['width'] = "%d%%" % int(round(prop * 100))
+        elif tag == 'hr' and asfloat(style['width']) > 0 and style._get('width') not in {'100%', 'auto'}:
+            raww = style._get('width')
+            if hasattr(raww, 'strip') and '%' in raww:
+                istate.attrib['width'] = raww
+            else:
+                prop = style['width'] / self.profile.width
+                istate.attrib['width'] = "%d%%" % int(round(prop * 100))
         elif display == 'table':
             tag = 'table'
         elif display == 'table-row':
