@@ -1105,15 +1105,15 @@ class Cover(ImageView):  # {{{
         self.current_val = None
 
     def trim_cover(self, *args):
-        from calibre.utils.magick import Image
         cdata = self.current_val
         if not cdata:
             return
-        im = Image()
-        im.load(cdata)
-        im.trim(tweaks['cover_trim_fuzz_value'])
-        self.current_val = im.export('png')
-        self.cdata_before_trim = cdata
+        from calibre.utils.img import remove_borders_from_image, image_to_data, image_from_data
+        img = image_from_data(cdata)
+        nimg = remove_borders_from_image(img)
+        if nimg is not img:
+            self.cdata_before_trim = cdata
+            self.current_val = image_to_data(nimg, fmt='png')
 
     def manual_trim_cover(self):
         cdata = self.current_val
@@ -1206,6 +1206,7 @@ class Cover(ImageView):  # {{{
 class CommentsEdit(Editor, ToMetadataMixin):  # {{{
 
     FIELD_NAME = 'comments'
+    toolbar_prefs_name = 'metadata-comments-editor-widget-hidden-toolbars'
 
     @dynamic_property
     def current_val(self):
@@ -1241,6 +1242,7 @@ class RatingEdit(make_undoable(QSpinBox), ToMetadataMixin):  # {{{
         self.setWhatsThis(self.TOOLTIP)
         self.setMaximum(5)
         self.setSuffix(' ' + _('stars'))
+        self.setSpecialValueText(_('Not rated'))
 
     @dynamic_property
     def current_val(self):
@@ -1284,6 +1286,7 @@ class TagsEdit(EditWithComplete, ToMetadataMixin):  # {{{
 
     def __init__(self, parent):
         EditWithComplete.__init__(self, parent)
+        self.lineEdit().setMaxLength(65536)  # see https://bugs.launchpad.net/bugs/1569388
         self.books_to_refresh = set([])
         self.setToolTip(self.TOOLTIP)
         self.setWhatsThis(self.TOOLTIP)
@@ -1376,6 +1379,7 @@ class LanguagesEdit(LE, ToMetadataMixin):  # {{{
         cv = self.current_val
         if cv != self.original_val:
             db.set_languages(id_, cv)
+        self.update_recently_used()
 # }}}
 
 # Identifiers {{{
@@ -1520,9 +1524,11 @@ class IdentifiersEdit(QLineEdit, ToMetadataMixin):
             text = d.text()
             if not text:
                 return
-        vals = self.current_val
-        vals['isbn'] = text
-        self.current_val = vals
+        text = check_isbn(text)
+        if text:
+            vals = self.current_val
+            vals['isbn'] = text
+            self.current_val = vals
 
 # }}}
 
