@@ -90,20 +90,20 @@ def get_gui():
 
 def add_quick_start_guide(library_view, refresh_cover_browser=None):
     from calibre.ebooks.metadata.meta import get_metadata
-    from calibre.ebooks import calibre_cover
+    from calibre.ebooks.covers import calibre_cover2
     from calibre.utils.zipfile import safe_replace
     from calibre.utils.localization import get_lang, canonicalize_lang
     from calibre.ptempfile import PersistentTemporaryFile
     l = canonicalize_lang(get_lang()) or 'eng'
     gprefs['quick_start_guide_added'] = True
-    imgbuf = BytesIO(calibre_cover(_('Quick Start Guide'), '', author_size=8))
+    imgbuf = BytesIO(calibre_cover2(_('Quick Start Guide'), ''))
     try:
-        with open(P('quick_start/%s.epub' % l), 'rb') as src:
+        with lopen(P('quick_start/%s.epub' % l), 'rb') as src:
             buf = BytesIO(src.read())
     except EnvironmentError as err:
         if err.errno != errno.ENOENT:
             raise
-        with open(P('quick_start/eng.epub'), 'rb') as src:
+        with lopen(P('quick_start/eng.epub'), 'rb') as src:
             buf = BytesIO(src.read())
     safe_replace(buf, 'images/cover.jpg', imgbuf)
     buf.seek(0)
@@ -129,6 +129,7 @@ class Main(MainWindow, MainWindowMixin, DeviceMixin, EmailMixin,  # {{{
 
     proceed_requested = pyqtSignal(object, object)
     book_converted = pyqtSignal(object, object)
+    shutting_down = False
 
     def __init__(self, opts, parent=None, gui_debug=None):
         global _gui
@@ -288,6 +289,11 @@ class Main(MainWindow, MainWindowMixin, DeviceMixin, EmailMixin,  # {{{
             self.system_tray_icon.activated.connect(self.system_tray_icon_activated)
         self.quit_action.triggered[bool].connect(self.quit)
         self.donate_action.triggered[bool].connect(self.donate)
+        self.minimize_action = QAction(_('Minimize the calibre window'), self)
+        self.addAction(self.minimize_action)
+        self.keyboard.register_shortcut('minimize calibre', self.minimize_action.text(),
+                default_keys=(), action=self.minimize_action)
+        self.minimize_action.triggered.connect(self.showMinimized)
 
         self.esc_action = QAction(self)
         self.addAction(self.esc_action)
@@ -331,7 +337,7 @@ class Main(MainWindow, MainWindowMixin, DeviceMixin, EmailMixin,  # {{{
         UpdateMixin.init_update_mixin(self, opts)
 
         # ###################### Search boxes ########################
-        SearchRestrictionMixin.init_search_restirction_mixin(self)
+        SearchRestrictionMixin.init_search_restriction_mixin(self)
         SavedSearchBoxMixin.init_saved_seach_box_mixin(self)
 
         # ###################### Library view ########################
@@ -391,8 +397,6 @@ class Main(MainWindow, MainWindowMixin, DeviceMixin, EmailMixin,  # {{{
         if config['autolaunch_server']:
             self.start_content_server()
 
-        self.keyboard_interrupt.connect(self.quit, type=Qt.QueuedConnection)
-
         self.read_settings()
         self.finalize_layout()
         if self.bars_manager.showing_donate:
@@ -419,6 +423,7 @@ class Main(MainWindow, MainWindowMixin, DeviceMixin, EmailMixin,  # {{{
         # Collect cycles now
         gc.collect()
 
+        QApplication.instance().shutdown_signal_received.connect(self.quit)
         if show_gui and self.gui_debug is not None:
             QTimer.singleShot(10, self.show_gui_debug_msg)
 
@@ -837,6 +842,8 @@ class Main(MainWindow, MainWindowMixin, DeviceMixin, EmailMixin,  # {{{
 
     def quit(self, checked=True, restart=False, debug_on_restart=False,
             confirm_quit=True):
+        if self.shutting_down:
+            return
         if confirm_quit and not self.confirm_quit():
             return
         try:
@@ -848,7 +855,7 @@ class Main(MainWindow, MainWindowMixin, DeviceMixin, EmailMixin,  # {{{
         QApplication.instance().quit()
 
     def donate(self, *args):
-        open_url(QUrl('http://calibre-ebook.com/donate'))
+        open_url(QUrl('https://calibre-ebook.com/donate'))
 
     def confirm_quit(self):
         if self.job_manager.has_jobs():
@@ -861,6 +868,12 @@ class Main(MainWindow, MainWindowMixin, DeviceMixin, EmailMixin,  # {{{
 
             if not question_dialog(self, _('Active jobs'), msg):
                 return False
+
+        if self.proceed_question.questions:
+            msg = _('There are library updates waiting. Are you sure you want to quit?')
+            if not question_dialog(self, _('Library Updates Waiting'), msg):
+                return False
+
         from calibre.db.delete_service import has_jobs
         if has_jobs():
             msg = _('Some deleted books are still being moved to the Recycle '
@@ -872,7 +885,16 @@ class Main(MainWindow, MainWindowMixin, DeviceMixin, EmailMixin,  # {{{
         return True
 
     def shutdown(self, write_settings=True):
+        self.shutting_down = True
+        self.show_shutdown_message()
+
+        from calibre.customize.ui import has_library_closed_plugins
+        if has_library_closed_plugins():
+            self.show_shutdown_message(
+                _('Running database shutdown plugins. This could take a few seconds...'))
+
         self.grid_view.shutdown()
+        db = None
         try:
             db = self.library_view.model().db
             cf = db.clean
@@ -898,14 +920,32 @@ class Main(MainWindow, MainWindowMixin, DeviceMixin, EmailMixin,  # {{{
         self.job_manager.threaded_server.close()
         self.device_manager.keep_going = False
         self.auto_adder.stop()
+        # Do not report any errors that happen after the shutdown
+        # We cannot restore the original excepthook as that causes PyQt to
+        # call abort() on unhandled exceptions
+        import traceback
+        def eh(t, v, tb):
+            try:
+                traceback.print_exception(t, v, tb, file=sys.stderr)
+            except:
+                pass
+        sys.excepthook = eh
+
         mb = self.library_view.model().metadata_backup
         if mb is not None:
             mb.stop()
 
-        self.hide_windows()
+        if db is not None:
+            db.close()
+
         try:
             try:
                 if self.content_server is not None:
+                    # If the content server has any sockets being closed then
+                    # this can take quite a long time (minutes). Tell the user that it is
+                    # happening.
+                    self.show_shutdown_message(
+                        _('Shutting down the content server. This could take a while ...'))
                     s = self.content_server
                     self.content_server = None
                     s.exit()
@@ -913,15 +953,13 @@ class Main(MainWindow, MainWindowMixin, DeviceMixin, EmailMixin,  # {{{
                 pass
         except KeyboardInterrupt:
             pass
+        self.hide_windows()
         if self._spare_pool is not None:
             self._spare_pool.shutdown()
         from calibre.db.delete_service import shutdown
         shutdown()
         time.sleep(2)
         self.istores.join()
-        self.hide_windows()
-        # Do not report any errors that happen after the shutdown
-        sys.excepthook = sys.__excepthook__
         return True
 
     def run_wizard(self, *args):
@@ -935,6 +973,8 @@ class Main(MainWindow, MainWindowMixin, DeviceMixin, EmailMixin,  # {{{
             QApplication.instance().quit()
 
     def closeEvent(self, e):
+        if self.shutting_down:
+            return
         self.write_settings()
         if self.system_tray_icon is not None and self.system_tray_icon.isVisible():
             if not dynamic['systray_msg'] and not isosx:
